@@ -2,21 +2,10 @@
 tuneR_read_mp3_or_wav <- function(filepath, from = 0, to = Inf, unit = "samples") {
   file_ext <- tools::file_ext(filepath)
   unit <- unit[1]
-  if(file_ext == "mp3") {
-    info <- info(filepath)
-    to_ <- to
-    from_ <- from
-    duration <- info$num_frames
-    if(unit == "samples") {
-      from_ <-max(1, from_)/info$sample_rate
-      to_ <- to_/info$sample_rate
-      duration <- duration/info$sample_rate
-    }
-    to_ <- min(to_, duration)
-    to_ <- max(to_, from_ + 0.015)
-    to_ <- 0.05 + to_*1.01
-    wave_obj <- monitoR::readMP3(filepath, from = from_, to = to_)
-    wave_obj <- tuneR::extractWave(wave_obj, from = unit=="samples", to = to - from, xunit = unit)
+  if( file_ext == "mp3") {
+      wave_obj <- tuneR::readMP3(filepath)
+      if(from > 0 | is.finite(to))
+      wave_obj <- tuneR::extractWave(wave_obj, from = unit=="samples", to = to - from, xunit = unit)
   } else if(file_ext == "wav") {
     if(unit == "time") unit <- "seconds"
     if(unit %in% c("samples", "sample")) {
